@@ -21,11 +21,11 @@
 #endif
 
 #include <gtk/gtk.h>
-#include <libxfce4util/libxfce4util.h>
 
 #include "common.h"
 #include "actions.h"
 #include "history.h"
+#include <libxfce4util/libxfce4util.h>
 
 #include "collector.h"
 
@@ -145,12 +145,22 @@ cb_clipboard_owner_change (ClipmanCollector *collector,
 static gboolean
 cb_check_primary_clipboard (ClipmanCollector *collector)
 {
-  GdkModifierType state;
+  GdkModifierType state = 0;
+  GdkDisplay* display = gdk_display_get_default ();
+#if GTK_CHECK_VERSION (3, 20, 0)
+  GdkSeat *seat = gdk_display_get_default_seat (display);
+  GdkDevice *device = gdk_seat_get_pointer (seat);
+#else
+  GdkDeviceManager *device_manager = gdk_display_get_device_manager (display);
+  GdkDevice *device = gdk_device_manager_get_client_pointer (device_manager);
+#endif
+  GdkScreen* screen = gdk_screen_get_default ();
+  GdkWindow * root_win = gdk_screen_get_root_window (screen);
 
   g_return_val_if_fail (GTK_IS_CLIPBOARD (collector->priv->default_clipboard) && GTK_IS_CLIPBOARD (collector->priv->primary_clipboard), FALSE);
 
   /* Postpone until the selection is done */
-  gdk_window_get_pointer (NULL, NULL, NULL, &state);
+  gdk_window_get_device_position (root_win, device, NULL, NULL, &state);
   if (state & (GDK_BUTTON1_MASK|GDK_SHIFT_MASK))
     return TRUE;
 
@@ -239,6 +249,43 @@ clipman_collector_get (void)
   return singleton;
 }
 
+void
+clipman_collector_show_actions (void)
+{
+  ClipmanCollector   *collector;
+  const ClipmanHistoryItem *item;
+  ClipmanHistory     *history;
+  GSList *entries;
+  gint group;
+
+  history = clipman_history_get();
+  collector = clipman_collector_get();
+
+  item = clipman_history_get_item_to_restore(history);
+
+  if (item == NULL)
+    return;
+
+  if (item->type == CLIPMAN_HISTORY_TYPE_TEXT)
+    {
+      entries = clipman_actions_match (collector->priv->actions, ACTION_GROUP_MANUAL, item->content.text);
+      if (entries == NULL)
+        {
+          group = ACTION_GROUP_SELECTION;
+        }
+      else
+        {
+          group = ACTION_GROUP_MANUAL;
+        }
+      g_slist_free (entries);
+      clipman_actions_match_with_menu (collector->priv->actions, group, item->content.text);
+    }
+  else
+    {
+      DBG("I can't show actions on item type %d", item->type);
+    }
+}
+
 /*
  * GObject
  */
@@ -386,4 +433,3 @@ clipman_collector_get_property (GObject *object,
       break;
     }
 }
-
