@@ -334,8 +334,8 @@ plugin_about (MyPlugin *plugin)
                          "version", PACKAGE_VERSION,
                          "copyright", "Copyright © 2003-2016 The Xfce development team",
                          "license", license,
-                         "website", "http://goodies.xfce.org/projects/panel-plugins/xfce4-clipman-plugin",
-                         "website-label", "goodies.xfce.org",
+                         "website", "https://docs.xfce.org/panel-plugins/xfce4-clipman-plugin",
+                         "website-label", "docs.xfce.org",
                          "authors", authors,
                          "documenters", documenters,
                          "translator-credits", _("translator-credits"),
