@@ -212,7 +212,7 @@ default_clipboard_owner_change (GsdClipboardManager *manager,
 static gboolean
 primary_clipboard_store (GsdClipboardManager *manager)
 {
-        GdkModifierType state;
+        GdkModifierType state = 0;
         gchar *text;
         GdkDisplay* display = gdk_display_get_default ();
 #if GTK_CHECK_VERSION (3, 20, 0)
@@ -222,8 +222,10 @@ primary_clipboard_store (GsdClipboardManager *manager)
         GdkDeviceManager *device_manager = gdk_display_get_device_manager (display);
         GdkDevice *device = gdk_device_manager_get_client_pointer (device_manager);
 #endif
+        GdkScreen* screen = gdk_screen_get_default ();
+        GdkWindow * root_win = gdk_screen_get_root_window (screen);
 
-        gdk_window_get_device_position (NULL, device, NULL, NULL, &state);
+        gdk_window_get_device_position (root_win, device, NULL, NULL, &state);
         if (state & (GDK_BUTTON1_MASK|GDK_SHIFT_MASK)) {
                 return TRUE;
         }
